c3errors.C3Exception

|  | ## Cheshire3 Object Model: Class C3Exception

Module c3errors :: Class C3Exception

## Class C3Exception
source code

Object Tree:

    exceptions.Exception --+
                           |
                          C3Exception

Known Subclasses:
  ConfigFileException, ExternalSystemException, FileDoesNotExistException, ObjectAlreadyExistsException, ObjectDoesNotExistException, PermissionException, record.NumericPredicateException, workflow.WorkflowException

Instance Methods

__init__(self, text="None")
__str__(self)
Inherited from `exceptions.Exception`: `__getitem__`

Class Variables

text |

Method Details

### __init__(self, text="None") (Constructor) | source code
Overrides: exceptions.Exception.__init__

### __str__(self) (Informal representation operator) | source code
Overrides: exceptions.Exception.__str__

Class Variable Details

    ### text Value:
        ''